# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from python_pachyderm.proto.v2.enterprise import enterprise_pb2 as python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2


class APIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Activate = channel.unary_unary(
                '/enterprise_v2.API/Activate',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.ActivateRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.ActivateResponse.FromString,
                )
        self.GetState = channel.unary_unary(
                '/enterprise_v2.API/GetState',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.GetStateRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.GetStateResponse.FromString,
                )
        self.GetActivationCode = channel.unary_unary(
                '/enterprise_v2.API/GetActivationCode',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.GetActivationCodeRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.GetActivationCodeResponse.FromString,
                )
        self.Heartbeat = channel.unary_unary(
                '/enterprise_v2.API/Heartbeat',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.HeartbeatRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.HeartbeatResponse.FromString,
                )
        self.Deactivate = channel.unary_unary(
                '/enterprise_v2.API/Deactivate',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.DeactivateRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.DeactivateResponse.FromString,
                )


class APIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Activate(self, request, context):
        """Provide a Pachyderm enterprise token, enabling Pachyderm enterprise
        features, such as the Pachyderm Dashboard and Auth system
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActivationCode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Heartbeat(self, request, context):
        """Heartbeat is used in testing to trigger a heartbeat on demand. Normally this happens
        on a timer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deactivate(self, request, context):
        """Deactivate removes a cluster's enterprise activation
        token and sets its enterprise state to NONE.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_APIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Activate': grpc.unary_unary_rpc_method_handler(
                    servicer.Activate,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.ActivateRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.ActivateResponse.SerializeToString,
            ),
            'GetState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetState,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.GetStateRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.GetStateResponse.SerializeToString,
            ),
            'GetActivationCode': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActivationCode,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.GetActivationCodeRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.GetActivationCodeResponse.SerializeToString,
            ),
            'Heartbeat': grpc.unary_unary_rpc_method_handler(
                    servicer.Heartbeat,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.HeartbeatRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.HeartbeatResponse.SerializeToString,
            ),
            'Deactivate': grpc.unary_unary_rpc_method_handler(
                    servicer.Deactivate,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.DeactivateRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.DeactivateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'enterprise_v2.API', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class API(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Activate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/enterprise_v2.API/Activate',
            python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.ActivateRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.ActivateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/enterprise_v2.API/GetState',
            python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.GetStateRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.GetStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActivationCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/enterprise_v2.API/GetActivationCode',
            python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.GetActivationCodeRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.GetActivationCodeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Heartbeat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/enterprise_v2.API/Heartbeat',
            python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.HeartbeatRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.HeartbeatResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deactivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/enterprise_v2.API/Deactivate',
            python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.DeactivateRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.DeactivateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
