# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from python_pachyderm.proto.v2.pfs import pfs_pb2 as python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2


class APIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateRepo = channel.unary_unary(
                '/pfs_v2.API/CreateRepo',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CreateRepoRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.InspectRepo = channel.unary_unary(
                '/pfs_v2.API/InspectRepo',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectRepoRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RepoInfo.FromString,
                )
        self.ListRepo = channel.unary_stream(
                '/pfs_v2.API/ListRepo',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListRepoRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RepoInfo.FromString,
                )
        self.DeleteRepo = channel.unary_unary(
                '/pfs_v2.API/DeleteRepo',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DeleteRepoRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StartCommit = channel.unary_unary(
                '/pfs_v2.API/StartCommit',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.StartCommitRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.Commit.FromString,
                )
        self.FinishCommit = channel.unary_unary(
                '/pfs_v2.API/FinishCommit',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FinishCommitRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ClearCommit = channel.unary_unary(
                '/pfs_v2.API/ClearCommit',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ClearCommitRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.InspectCommit = channel.unary_unary(
                '/pfs_v2.API/InspectCommit',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectCommitRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitInfo.FromString,
                )
        self.ListCommit = channel.unary_stream(
                '/pfs_v2.API/ListCommit',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListCommitRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitInfo.FromString,
                )
        self.SubscribeCommit = channel.unary_stream(
                '/pfs_v2.API/SubscribeCommit',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.SubscribeCommitRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitInfo.FromString,
                )
        self.InspectCommitSet = channel.unary_stream(
                '/pfs_v2.API/InspectCommitSet',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectCommitSetRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitInfo.FromString,
                )
        self.ListCommitSet = channel.unary_stream(
                '/pfs_v2.API/ListCommitSet',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListCommitSetRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitSetInfo.FromString,
                )
        self.SquashCommitSet = channel.unary_unary(
                '/pfs_v2.API/SquashCommitSet',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.SquashCommitSetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DropCommitSet = channel.unary_unary(
                '/pfs_v2.API/DropCommitSet',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DropCommitSetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateBranch = channel.unary_unary(
                '/pfs_v2.API/CreateBranch',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CreateBranchRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.InspectBranch = channel.unary_unary(
                '/pfs_v2.API/InspectBranch',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectBranchRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.BranchInfo.FromString,
                )
        self.ListBranch = channel.unary_stream(
                '/pfs_v2.API/ListBranch',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListBranchRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.BranchInfo.FromString,
                )
        self.DeleteBranch = channel.unary_unary(
                '/pfs_v2.API/DeleteBranch',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DeleteBranchRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ModifyFile = channel.stream_unary(
                '/pfs_v2.API/ModifyFile',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ModifyFileRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetFile = channel.unary_stream(
                '/pfs_v2.API/GetFile',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.GetFileRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
                )
        self.GetFileTAR = channel.unary_stream(
                '/pfs_v2.API/GetFileTAR',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.GetFileRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
                )
        self.InspectFile = channel.unary_unary(
                '/pfs_v2.API/InspectFile',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectFileRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FileInfo.FromString,
                )
        self.ListFile = channel.unary_stream(
                '/pfs_v2.API/ListFile',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListFileRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FileInfo.FromString,
                )
        self.WalkFile = channel.unary_stream(
                '/pfs_v2.API/WalkFile',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.WalkFileRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FileInfo.FromString,
                )
        self.GlobFile = channel.unary_stream(
                '/pfs_v2.API/GlobFile',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.GlobFileRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FileInfo.FromString,
                )
        self.DiffFile = channel.unary_stream(
                '/pfs_v2.API/DiffFile',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DiffFileRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DiffFileResponse.FromString,
                )
        self.ActivateAuth = channel.unary_unary(
                '/pfs_v2.API/ActivateAuth',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ActivateAuthRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ActivateAuthResponse.FromString,
                )
        self.DeleteAll = channel.unary_unary(
                '/pfs_v2.API/DeleteAll',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Fsck = channel.unary_stream(
                '/pfs_v2.API/Fsck',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FsckRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FsckResponse.FromString,
                )
        self.CreateFileSet = channel.stream_unary(
                '/pfs_v2.API/CreateFileSet',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ModifyFileRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CreateFileSetResponse.FromString,
                )
        self.GetFileSet = channel.unary_unary(
                '/pfs_v2.API/GetFileSet',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.GetFileSetRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CreateFileSetResponse.FromString,
                )
        self.AddFileSet = channel.unary_unary(
                '/pfs_v2.API/AddFileSet',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.AddFileSetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RenewFileSet = channel.unary_unary(
                '/pfs_v2.API/RenewFileSet',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RenewFileSetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RunLoadTest = channel.unary_unary(
                '/pfs_v2.API/RunLoadTest',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestResponse.FromString,
                )
        self.RunLoadTestDefault = channel.unary_unary(
                '/pfs_v2.API/RunLoadTestDefault',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestResponse.FromString,
                )


class APIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateRepo(self, request, context):
        """CreateRepo creates a new repo.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectRepo(self, request, context):
        """InspectRepo returns info about a repo.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRepo(self, request, context):
        """ListRepo returns info about all repos.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRepo(self, request, context):
        """DeleteRepo deletes a repo.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartCommit(self, request, context):
        """StartCommit creates a new write commit from a parent commit.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FinishCommit(self, request, context):
        """FinishCommit turns a write commit into a read commit.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearCommit(self, request, context):
        """ClearCommit removes all data from the commit.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectCommit(self, request, context):
        """InspectCommit returns the info about a commit.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCommit(self, request, context):
        """ListCommit returns info about all commits.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeCommit(self, request, context):
        """SubscribeCommit subscribes for new commits on a given branch.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectCommitSet(self, request, context):
        """InspectCommitSet returns the info about a CommitSet.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCommitSet(self, request, context):
        """ListCommitSet returns info about all CommitSets.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SquashCommitSet(self, request, context):
        """SquashCommitSet squashes the commits of a CommitSet into their children.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DropCommitSet(self, request, context):
        """DropCommitSet drops the commits of a CommitSet and all data included in the commits.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateBranch(self, request, context):
        """CreateBranch creates a new branch.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectBranch(self, request, context):
        """InspectBranch returns info about a branch.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBranch(self, request, context):
        """ListBranch returns info about the heads of branches.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBranch(self, request, context):
        """DeleteBranch deletes a branch; note that the commits still exist.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModifyFile(self, request_iterator, context):
        """ModifyFile performs modifications on a set of files.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFile(self, request, context):
        """GetFile returns the contents of a single file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFileTAR(self, request, context):
        """GetFileTAR returns a TAR stream of the contents matched by the request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectFile(self, request, context):
        """InspectFile returns info about a file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFile(self, request, context):
        """ListFile returns info about all files.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WalkFile(self, request, context):
        """WalkFile walks over all the files under a directory, including children of children.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GlobFile(self, request, context):
        """GlobFile returns info about all files.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DiffFile(self, request, context):
        """DiffFile returns the differences between 2 paths at 2 commits.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateAuth(self, request, context):
        """ActivateAuth creates a role binding for all existing repos
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAll(self, request, context):
        """DeleteAll deletes everything.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Fsck(self, request, context):
        """Fsck does a file system consistency check for pfs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFileSet(self, request_iterator, context):
        """FileSet API
        CreateFileSet creates a new file set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFileSet(self, request, context):
        """GetFileSet returns a file set with the data from a commit
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddFileSet(self, request, context):
        """AddFileSet associates a file set with a commit
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenewFileSet(self, request, context):
        """RenewFileSet prevents a file set from being deleted for a set amount of time.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunLoadTest(self, request, context):
        """RunLoadTest runs a load test.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunLoadTestDefault(self, request, context):
        """RunLoadTestDefault runs the default load tests.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_APIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateRepo': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRepo,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CreateRepoRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'InspectRepo': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectRepo,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectRepoRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RepoInfo.SerializeToString,
            ),
            'ListRepo': grpc.unary_stream_rpc_method_handler(
                    servicer.ListRepo,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListRepoRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RepoInfo.SerializeToString,
            ),
            'DeleteRepo': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRepo,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DeleteRepoRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StartCommit': grpc.unary_unary_rpc_method_handler(
                    servicer.StartCommit,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.StartCommitRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.Commit.SerializeToString,
            ),
            'FinishCommit': grpc.unary_unary_rpc_method_handler(
                    servicer.FinishCommit,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FinishCommitRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ClearCommit': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearCommit,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ClearCommitRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'InspectCommit': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectCommit,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectCommitRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitInfo.SerializeToString,
            ),
            'ListCommit': grpc.unary_stream_rpc_method_handler(
                    servicer.ListCommit,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListCommitRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitInfo.SerializeToString,
            ),
            'SubscribeCommit': grpc.unary_stream_rpc_method_handler(
                    servicer.SubscribeCommit,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.SubscribeCommitRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitInfo.SerializeToString,
            ),
            'InspectCommitSet': grpc.unary_stream_rpc_method_handler(
                    servicer.InspectCommitSet,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectCommitSetRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitInfo.SerializeToString,
            ),
            'ListCommitSet': grpc.unary_stream_rpc_method_handler(
                    servicer.ListCommitSet,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListCommitSetRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitSetInfo.SerializeToString,
            ),
            'SquashCommitSet': grpc.unary_unary_rpc_method_handler(
                    servicer.SquashCommitSet,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.SquashCommitSetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DropCommitSet': grpc.unary_unary_rpc_method_handler(
                    servicer.DropCommitSet,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DropCommitSetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateBranch': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBranch,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CreateBranchRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'InspectBranch': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectBranch,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectBranchRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.BranchInfo.SerializeToString,
            ),
            'ListBranch': grpc.unary_stream_rpc_method_handler(
                    servicer.ListBranch,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListBranchRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.BranchInfo.SerializeToString,
            ),
            'DeleteBranch': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBranch,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DeleteBranchRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ModifyFile': grpc.stream_unary_rpc_method_handler(
                    servicer.ModifyFile,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ModifyFileRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetFile': grpc.unary_stream_rpc_method_handler(
                    servicer.GetFile,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.GetFileRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
            ),
            'GetFileTAR': grpc.unary_stream_rpc_method_handler(
                    servicer.GetFileTAR,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.GetFileRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
            ),
            'InspectFile': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectFile,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectFileRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FileInfo.SerializeToString,
            ),
            'ListFile': grpc.unary_stream_rpc_method_handler(
                    servicer.ListFile,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListFileRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FileInfo.SerializeToString,
            ),
            'WalkFile': grpc.unary_stream_rpc_method_handler(
                    servicer.WalkFile,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.WalkFileRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FileInfo.SerializeToString,
            ),
            'GlobFile': grpc.unary_stream_rpc_method_handler(
                    servicer.GlobFile,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.GlobFileRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FileInfo.SerializeToString,
            ),
            'DiffFile': grpc.unary_stream_rpc_method_handler(
                    servicer.DiffFile,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DiffFileRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DiffFileResponse.SerializeToString,
            ),
            'ActivateAuth': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateAuth,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ActivateAuthRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ActivateAuthResponse.SerializeToString,
            ),
            'DeleteAll': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAll,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Fsck': grpc.unary_stream_rpc_method_handler(
                    servicer.Fsck,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FsckRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FsckResponse.SerializeToString,
            ),
            'CreateFileSet': grpc.stream_unary_rpc_method_handler(
                    servicer.CreateFileSet,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ModifyFileRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CreateFileSetResponse.SerializeToString,
            ),
            'GetFileSet': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFileSet,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.GetFileSetRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CreateFileSetResponse.SerializeToString,
            ),
            'AddFileSet': grpc.unary_unary_rpc_method_handler(
                    servicer.AddFileSet,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.AddFileSetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RenewFileSet': grpc.unary_unary_rpc_method_handler(
                    servicer.RenewFileSet,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RenewFileSetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RunLoadTest': grpc.unary_unary_rpc_method_handler(
                    servicer.RunLoadTest,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestResponse.SerializeToString,
            ),
            'RunLoadTestDefault': grpc.unary_unary_rpc_method_handler(
                    servicer.RunLoadTestDefault,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'pfs_v2.API', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class API(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateRepo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/CreateRepo',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CreateRepoRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectRepo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/InspectRepo',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectRepoRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RepoInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRepo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/ListRepo',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListRepoRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RepoInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRepo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/DeleteRepo',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DeleteRepoRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartCommit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/StartCommit',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.StartCommitRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.Commit.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FinishCommit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/FinishCommit',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FinishCommitRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearCommit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/ClearCommit',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ClearCommitRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectCommit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/InspectCommit',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectCommitRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCommit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/ListCommit',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListCommitRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubscribeCommit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/SubscribeCommit',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.SubscribeCommitRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectCommitSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/InspectCommitSet',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectCommitSetRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCommitSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/ListCommitSet',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListCommitSetRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CommitSetInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SquashCommitSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/SquashCommitSet',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.SquashCommitSetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DropCommitSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/DropCommitSet',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DropCommitSetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateBranch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/CreateBranch',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CreateBranchRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectBranch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/InspectBranch',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectBranchRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.BranchInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBranch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/ListBranch',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListBranchRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.BranchInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteBranch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/DeleteBranch',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DeleteBranchRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ModifyFile(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/pfs_v2.API/ModifyFile',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ModifyFileRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/GetFile',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.GetFileRequest.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFileTAR(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/GetFileTAR',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.GetFileRequest.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/InspectFile',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.InspectFileRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FileInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/ListFile',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ListFileRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FileInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WalkFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/WalkFile',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.WalkFileRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FileInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GlobFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/GlobFile',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.GlobFileRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FileInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DiffFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/DiffFile',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DiffFileRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.DiffFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateAuth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/ActivateAuth',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ActivateAuthRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ActivateAuthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/DeleteAll',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Fsck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pfs_v2.API/Fsck',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FsckRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.FsckResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFileSet(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/pfs_v2.API/CreateFileSet',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.ModifyFileRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CreateFileSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFileSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/GetFileSet',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.GetFileSetRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.CreateFileSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddFileSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/AddFileSet',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.AddFileSetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenewFileSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/RenewFileSet',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RenewFileSetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunLoadTest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/RunLoadTest',
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunLoadTestDefault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pfs_v2.API/RunLoadTestDefault',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
