# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from python_pachyderm.proto.v2.identity import identity_pb2 as python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2


class APIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetIdentityServerConfig = channel.unary_unary(
                '/identity_v2.API/SetIdentityServerConfig',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.SetIdentityServerConfigRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.SetIdentityServerConfigResponse.FromString,
                )
        self.GetIdentityServerConfig = channel.unary_unary(
                '/identity_v2.API/GetIdentityServerConfig',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetIdentityServerConfigRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetIdentityServerConfigResponse.FromString,
                )
        self.CreateIDPConnector = channel.unary_unary(
                '/identity_v2.API/CreateIDPConnector',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.CreateIDPConnectorRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.CreateIDPConnectorResponse.FromString,
                )
        self.UpdateIDPConnector = channel.unary_unary(
                '/identity_v2.API/UpdateIDPConnector',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.UpdateIDPConnectorRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.UpdateIDPConnectorResponse.FromString,
                )
        self.ListIDPConnectors = channel.unary_unary(
                '/identity_v2.API/ListIDPConnectors',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.ListIDPConnectorsRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.ListIDPConnectorsResponse.FromString,
                )
        self.GetIDPConnector = channel.unary_unary(
                '/identity_v2.API/GetIDPConnector',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetIDPConnectorRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetIDPConnectorResponse.FromString,
                )
        self.DeleteIDPConnector = channel.unary_unary(
                '/identity_v2.API/DeleteIDPConnector',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteIDPConnectorRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteIDPConnectorResponse.FromString,
                )
        self.CreateOIDCClient = channel.unary_unary(
                '/identity_v2.API/CreateOIDCClient',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.CreateOIDCClientRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.CreateOIDCClientResponse.FromString,
                )
        self.UpdateOIDCClient = channel.unary_unary(
                '/identity_v2.API/UpdateOIDCClient',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.UpdateOIDCClientRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.UpdateOIDCClientResponse.FromString,
                )
        self.GetOIDCClient = channel.unary_unary(
                '/identity_v2.API/GetOIDCClient',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetOIDCClientRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetOIDCClientResponse.FromString,
                )
        self.ListOIDCClients = channel.unary_unary(
                '/identity_v2.API/ListOIDCClients',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.ListOIDCClientsRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.ListOIDCClientsResponse.FromString,
                )
        self.DeleteOIDCClient = channel.unary_unary(
                '/identity_v2.API/DeleteOIDCClient',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteOIDCClientRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteOIDCClientResponse.FromString,
                )
        self.DeleteAll = channel.unary_unary(
                '/identity_v2.API/DeleteAll',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteAllRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteAllResponse.FromString,
                )


class APIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SetIdentityServerConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIdentityServerConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateIDPConnector(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateIDPConnector(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListIDPConnectors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIDPConnector(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIDPConnector(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOIDCClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOIDCClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOIDCClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOIDCClients(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOIDCClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAll(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_APIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetIdentityServerConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetIdentityServerConfig,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.SetIdentityServerConfigRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.SetIdentityServerConfigResponse.SerializeToString,
            ),
            'GetIdentityServerConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIdentityServerConfig,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetIdentityServerConfigRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetIdentityServerConfigResponse.SerializeToString,
            ),
            'CreateIDPConnector': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIDPConnector,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.CreateIDPConnectorRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.CreateIDPConnectorResponse.SerializeToString,
            ),
            'UpdateIDPConnector': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateIDPConnector,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.UpdateIDPConnectorRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.UpdateIDPConnectorResponse.SerializeToString,
            ),
            'ListIDPConnectors': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIDPConnectors,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.ListIDPConnectorsRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.ListIDPConnectorsResponse.SerializeToString,
            ),
            'GetIDPConnector': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIDPConnector,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetIDPConnectorRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetIDPConnectorResponse.SerializeToString,
            ),
            'DeleteIDPConnector': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIDPConnector,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteIDPConnectorRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteIDPConnectorResponse.SerializeToString,
            ),
            'CreateOIDCClient': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOIDCClient,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.CreateOIDCClientRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.CreateOIDCClientResponse.SerializeToString,
            ),
            'UpdateOIDCClient': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOIDCClient,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.UpdateOIDCClientRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.UpdateOIDCClientResponse.SerializeToString,
            ),
            'GetOIDCClient': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOIDCClient,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetOIDCClientRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetOIDCClientResponse.SerializeToString,
            ),
            'ListOIDCClients': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOIDCClients,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.ListOIDCClientsRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.ListOIDCClientsResponse.SerializeToString,
            ),
            'DeleteOIDCClient': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOIDCClient,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteOIDCClientRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteOIDCClientResponse.SerializeToString,
            ),
            'DeleteAll': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAll,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteAllRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteAllResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'identity_v2.API', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class API(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SetIdentityServerConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/SetIdentityServerConfig',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.SetIdentityServerConfigRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.SetIdentityServerConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIdentityServerConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/GetIdentityServerConfig',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetIdentityServerConfigRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetIdentityServerConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateIDPConnector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/CreateIDPConnector',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.CreateIDPConnectorRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.CreateIDPConnectorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateIDPConnector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/UpdateIDPConnector',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.UpdateIDPConnectorRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.UpdateIDPConnectorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListIDPConnectors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/ListIDPConnectors',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.ListIDPConnectorsRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.ListIDPConnectorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIDPConnector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/GetIDPConnector',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetIDPConnectorRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetIDPConnectorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteIDPConnector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/DeleteIDPConnector',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteIDPConnectorRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteIDPConnectorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOIDCClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/CreateOIDCClient',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.CreateOIDCClientRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.CreateOIDCClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOIDCClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/UpdateOIDCClient',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.UpdateOIDCClientRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.UpdateOIDCClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOIDCClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/GetOIDCClient',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetOIDCClientRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.GetOIDCClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOIDCClients(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/ListOIDCClients',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.ListOIDCClientsRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.ListOIDCClientsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOIDCClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/DeleteOIDCClient',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteOIDCClientRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteOIDCClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/identity_v2.API/DeleteAll',
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteAllRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_identity_dot_identity__pb2.DeleteAllResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
