# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: python_pachyderm/proto/v2/proxy/proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='python_pachyderm/proto/v2/proxy/proxy.proto',
  package='proxy',
  syntax='proto3',
  serialized_options=b'Z+github.com/pachyderm/pachyderm/v2/src/proxy',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+python_pachyderm/proto/v2/proxy/proxy.proto\x12\x05proxy\" \n\rListenRequest\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\"\x1f\n\x0eListenResponse\x12\r\n\x05\x65xtra\x18\x01 \x01(\t2@\n\x03\x41PI\x12\x39\n\x06Listen\x12\x14.proxy.ListenRequest\x1a\x15.proxy.ListenResponse\"\x00\x30\x01\x42-Z+github.com/pachyderm/pachyderm/v2/src/proxyb\x06proto3'
)




_LISTENREQUEST = _descriptor.Descriptor(
  name='ListenRequest',
  full_name='proxy.ListenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='proxy.ListenRequest.channel', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=86,
)


_LISTENRESPONSE = _descriptor.Descriptor(
  name='ListenResponse',
  full_name='proxy.ListenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extra', full_name='proxy.ListenResponse.extra', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=119,
)

DESCRIPTOR.message_types_by_name['ListenRequest'] = _LISTENREQUEST
DESCRIPTOR.message_types_by_name['ListenResponse'] = _LISTENRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListenRequest = _reflection.GeneratedProtocolMessageType('ListenRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTENREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.proxy.proxy_pb2'
  # @@protoc_insertion_point(class_scope:proxy.ListenRequest)
  })
_sym_db.RegisterMessage(ListenRequest)

ListenResponse = _reflection.GeneratedProtocolMessageType('ListenResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.proxy.proxy_pb2'
  # @@protoc_insertion_point(class_scope:proxy.ListenResponse)
  })
_sym_db.RegisterMessage(ListenResponse)


DESCRIPTOR._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='proxy.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=121,
  serialized_end=185,
  methods=[
  _descriptor.MethodDescriptor(
    name='Listen',
    full_name='proxy.API.Listen',
    index=0,
    containing_service=None,
    input_type=_LISTENREQUEST,
    output_type=_LISTENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)
