# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from python_pachyderm.proto.v2.pfs import pfs_pb2 as python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2
from python_pachyderm.proto.v2.pps import pps_pb2 as python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2


class APIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InspectJob = channel.unary_unary(
                '/pps_v2.API/InspectJob',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectJobRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
                )
        self.InspectJobSet = channel.unary_stream(
                '/pps_v2.API/InspectJobSet',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectJobSetRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
                )
        self.ListJob = channel.unary_stream(
                '/pps_v2.API/ListJob',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListJobRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
                )
        self.ListJobSet = channel.unary_stream(
                '/pps_v2.API/ListJobSet',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListJobSetRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobSetInfo.FromString,
                )
        self.SubscribeJob = channel.unary_stream(
                '/pps_v2.API/SubscribeJob',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SubscribeJobRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
                )
        self.DeleteJob = channel.unary_unary(
                '/pps_v2.API/DeleteJob',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeleteJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StopJob = channel.unary_unary(
                '/pps_v2.API/StopJob',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StopJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.InspectDatum = channel.unary_unary(
                '/pps_v2.API/InspectDatum',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectDatumRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DatumInfo.FromString,
                )
        self.ListDatum = channel.unary_stream(
                '/pps_v2.API/ListDatum',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListDatumRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DatumInfo.FromString,
                )
        self.RestartDatum = channel.unary_unary(
                '/pps_v2.API/RestartDatum',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RestartDatumRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreatePipeline = channel.unary_unary(
                '/pps_v2.API/CreatePipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.CreatePipelineRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.InspectPipeline = channel.unary_unary(
                '/pps_v2.API/InspectPipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectPipelineRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.PipelineInfo.FromString,
                )
        self.ListPipeline = channel.unary_stream(
                '/pps_v2.API/ListPipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListPipelineRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.PipelineInfo.FromString,
                )
        self.DeletePipeline = channel.unary_unary(
                '/pps_v2.API/DeletePipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeletePipelineRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StartPipeline = channel.unary_unary(
                '/pps_v2.API/StartPipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StartPipelineRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StopPipeline = channel.unary_unary(
                '/pps_v2.API/StopPipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StopPipelineRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RunPipeline = channel.unary_unary(
                '/pps_v2.API/RunPipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RunPipelineRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RunCron = channel.unary_unary(
                '/pps_v2.API/RunCron',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RunCronRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateSecret = channel.unary_unary(
                '/pps_v2.API/CreateSecret',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.CreateSecretRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteSecret = channel.unary_unary(
                '/pps_v2.API/DeleteSecret',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeleteSecretRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListSecret = channel.unary_unary(
                '/pps_v2.API/ListSecret',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SecretInfos.FromString,
                )
        self.InspectSecret = channel.unary_unary(
                '/pps_v2.API/InspectSecret',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectSecretRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SecretInfo.FromString,
                )
        self.DeleteAll = channel.unary_unary(
                '/pps_v2.API/DeleteAll',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetLogs = channel.unary_stream(
                '/pps_v2.API/GetLogs',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.GetLogsRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.LogMessage.FromString,
                )
        self.ActivateAuth = channel.unary_unary(
                '/pps_v2.API/ActivateAuth',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ActivateAuthRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ActivateAuthResponse.FromString,
                )
        self.UpdateJobState = channel.unary_unary(
                '/pps_v2.API/UpdateJobState',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.UpdateJobStateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RunLoadTestDefault = channel.unary_unary(
                '/pps_v2.API/RunLoadTestDefault',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestResponse.FromString,
                )


class APIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def InspectJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectJobSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListJob(self, request, context):
        """ListJob returns information about current and past Pachyderm jobs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListJobSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectDatum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDatum(self, request, context):
        """ListDatum returns information about each datum fed to a Pachyderm job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RestartDatum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunCron(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAll(self, request, context):
        """DeleteAll deletes everything
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateAuth(self, request, context):
        """An internal call that causes PPS to put itself into an auth-enabled state
        (all pipeline have tokens, correct permissions, etcd)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateJobState(self, request, context):
        """An internal call used to move a job from one state to another
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunLoadTestDefault(self, request, context):
        """RunLoadTest runs the default load test.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_APIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InspectJob': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectJob,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectJobRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.SerializeToString,
            ),
            'InspectJobSet': grpc.unary_stream_rpc_method_handler(
                    servicer.InspectJobSet,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectJobSetRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.SerializeToString,
            ),
            'ListJob': grpc.unary_stream_rpc_method_handler(
                    servicer.ListJob,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListJobRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.SerializeToString,
            ),
            'ListJobSet': grpc.unary_stream_rpc_method_handler(
                    servicer.ListJobSet,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListJobSetRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobSetInfo.SerializeToString,
            ),
            'SubscribeJob': grpc.unary_stream_rpc_method_handler(
                    servicer.SubscribeJob,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SubscribeJobRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.SerializeToString,
            ),
            'DeleteJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteJob,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeleteJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StopJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StopJob,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StopJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'InspectDatum': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectDatum,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectDatumRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DatumInfo.SerializeToString,
            ),
            'ListDatum': grpc.unary_stream_rpc_method_handler(
                    servicer.ListDatum,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListDatumRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DatumInfo.SerializeToString,
            ),
            'RestartDatum': grpc.unary_unary_rpc_method_handler(
                    servicer.RestartDatum,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RestartDatumRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreatePipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.CreatePipelineRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'InspectPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectPipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectPipelineRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.PipelineInfo.SerializeToString,
            ),
            'ListPipeline': grpc.unary_stream_rpc_method_handler(
                    servicer.ListPipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListPipelineRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.PipelineInfo.SerializeToString,
            ),
            'DeletePipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeletePipelineRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StartPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.StartPipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StartPipelineRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StopPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.StopPipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StopPipelineRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RunPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.RunPipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RunPipelineRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RunCron': grpc.unary_unary_rpc_method_handler(
                    servicer.RunCron,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RunCronRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSecret,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.CreateSecretRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSecret,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeleteSecretRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSecret,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SecretInfos.SerializeToString,
            ),
            'InspectSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectSecret,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectSecretRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SecretInfo.SerializeToString,
            ),
            'DeleteAll': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAll,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetLogs': grpc.unary_stream_rpc_method_handler(
                    servicer.GetLogs,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.GetLogsRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.LogMessage.SerializeToString,
            ),
            'ActivateAuth': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateAuth,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ActivateAuthRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ActivateAuthResponse.SerializeToString,
            ),
            'UpdateJobState': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateJobState,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.UpdateJobStateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RunLoadTestDefault': grpc.unary_unary_rpc_method_handler(
                    servicer.RunLoadTestDefault,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'pps_v2.API', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class API(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def InspectJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/InspectJob',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectJobRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectJobSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/InspectJobSet',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectJobSetRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/ListJob',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListJobRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListJobSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/ListJobSet',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListJobSetRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobSetInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubscribeJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/SubscribeJob',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SubscribeJobRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/DeleteJob',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeleteJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/StopJob',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StopJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectDatum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/InspectDatum',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectDatumRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DatumInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDatum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/ListDatum',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListDatumRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DatumInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RestartDatum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/RestartDatum',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RestartDatumRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/CreatePipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.CreatePipelineRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/InspectPipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectPipelineRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.PipelineInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/ListPipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListPipelineRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.PipelineInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/DeletePipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeletePipelineRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/StartPipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StartPipelineRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/StopPipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StopPipelineRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/RunPipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RunPipelineRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunCron(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/RunCron',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RunCronRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/CreateSecret',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.CreateSecretRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/DeleteSecret',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeleteSecretRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/ListSecret',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SecretInfos.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/InspectSecret',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectSecretRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SecretInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/DeleteAll',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/GetLogs',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.GetLogsRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.LogMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateAuth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/ActivateAuth',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ActivateAuthRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ActivateAuthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateJobState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/UpdateJobState',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.UpdateJobStateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunLoadTestDefault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/RunLoadTestDefault',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
