# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: python_pachyderm/proto/v2/identity/identity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='python_pachyderm/proto/v2/identity/identity.proto',
  package='identity_v2',
  syntax='proto3',
  serialized_options=b'Z.github.com/pachyderm/pachyderm/v2/src/identity',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1python_pachyderm/proto/v2/identity/identity.proto\x12\x0bidentity_v2\x1a\x1fgoogle/protobuf/timestamp.proto\"M\n\x04User\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x36\n\x12last_authenticated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"?\n\x14IdentityServerConfig\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x17\n\x0fid_token_expiry\x18\x02 \x01(\t\"S\n\x1eSetIdentityServerConfigRequest\x12\x31\n\x06\x63onfig\x18\x01 \x01(\x0b\x32!.identity_v2.IdentityServerConfig\"!\n\x1fSetIdentityServerConfigResponse\" \n\x1eGetIdentityServerConfigRequest\"T\n\x1fGetIdentityServerConfigResponse\x12\x31\n\x06\x63onfig\x18\x01 \x01(\x0b\x32!.identity_v2.IdentityServerConfig\"a\n\x0cIDPConnector\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x15\n\rconfigVersion\x18\x04 \x01(\x03\x12\x12\n\njsonConfig\x18\x05 \x01(\t\"I\n\x19\x43reateIDPConnectorRequest\x12,\n\tconnector\x18\x01 \x01(\x0b\x32\x19.identity_v2.IDPConnector\"\x1c\n\x1a\x43reateIDPConnectorResponse\"I\n\x19UpdateIDPConnectorRequest\x12,\n\tconnector\x18\x01 \x01(\x0b\x32\x19.identity_v2.IDPConnector\"\x1c\n\x1aUpdateIDPConnectorResponse\"\x1a\n\x18ListIDPConnectorsRequest\"J\n\x19ListIDPConnectorsResponse\x12-\n\nconnectors\x18\x01 \x03(\x0b\x32\x19.identity_v2.IDPConnector\"$\n\x16GetIDPConnectorRequest\x12\n\n\x02id\x18\x01 \x01(\t\"G\n\x17GetIDPConnectorResponse\x12,\n\tconnector\x18\x01 \x01(\x0b\x32\x19.identity_v2.IDPConnector\"\'\n\x19\x44\x65leteIDPConnectorRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1c\n\x1a\x44\x65leteIDPConnectorResponse\"d\n\nOIDCClient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rredirect_uris\x18\x02 \x03(\t\x12\x15\n\rtrusted_peers\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06secret\x18\x05 \x01(\t\"B\n\x17\x43reateOIDCClientRequest\x12\'\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x17.identity_v2.OIDCClient\"C\n\x18\x43reateOIDCClientResponse\x12\'\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x17.identity_v2.OIDCClient\"\"\n\x14GetOIDCClientRequest\x12\n\n\x02id\x18\x01 \x01(\t\"@\n\x15GetOIDCClientResponse\x12\'\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x17.identity_v2.OIDCClient\"\x18\n\x16ListOIDCClientsRequest\"C\n\x17ListOIDCClientsResponse\x12(\n\x07\x63lients\x18\x01 \x03(\x0b\x32\x17.identity_v2.OIDCClient\"B\n\x17UpdateOIDCClientRequest\x12\'\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x17.identity_v2.OIDCClient\"\x1a\n\x18UpdateOIDCClientResponse\"%\n\x17\x44\x65leteOIDCClientRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteOIDCClientResponse\"\x12\n\x10\x44\x65leteAllRequest\"\x13\n\x11\x44\x65leteAllResponse2\xa7\n\n\x03\x41PI\x12v\n\x17SetIdentityServerConfig\x12+.identity_v2.SetIdentityServerConfigRequest\x1a,.identity_v2.SetIdentityServerConfigResponse\"\x00\x12v\n\x17GetIdentityServerConfig\x12+.identity_v2.GetIdentityServerConfigRequest\x1a,.identity_v2.GetIdentityServerConfigResponse\"\x00\x12g\n\x12\x43reateIDPConnector\x12&.identity_v2.CreateIDPConnectorRequest\x1a\'.identity_v2.CreateIDPConnectorResponse\"\x00\x12g\n\x12UpdateIDPConnector\x12&.identity_v2.UpdateIDPConnectorRequest\x1a\'.identity_v2.UpdateIDPConnectorResponse\"\x00\x12\x64\n\x11ListIDPConnectors\x12%.identity_v2.ListIDPConnectorsRequest\x1a&.identity_v2.ListIDPConnectorsResponse\"\x00\x12^\n\x0fGetIDPConnector\x12#.identity_v2.GetIDPConnectorRequest\x1a$.identity_v2.GetIDPConnectorResponse\"\x00\x12g\n\x12\x44\x65leteIDPConnector\x12&.identity_v2.DeleteIDPConnectorRequest\x1a\'.identity_v2.DeleteIDPConnectorResponse\"\x00\x12\x61\n\x10\x43reateOIDCClient\x12$.identity_v2.CreateOIDCClientRequest\x1a%.identity_v2.CreateOIDCClientResponse\"\x00\x12\x61\n\x10UpdateOIDCClient\x12$.identity_v2.UpdateOIDCClientRequest\x1a%.identity_v2.UpdateOIDCClientResponse\"\x00\x12X\n\rGetOIDCClient\x12!.identity_v2.GetOIDCClientRequest\x1a\".identity_v2.GetOIDCClientResponse\"\x00\x12^\n\x0fListOIDCClients\x12#.identity_v2.ListOIDCClientsRequest\x1a$.identity_v2.ListOIDCClientsResponse\"\x00\x12\x61\n\x10\x44\x65leteOIDCClient\x12$.identity_v2.DeleteOIDCClientRequest\x1a%.identity_v2.DeleteOIDCClientResponse\"\x00\x12L\n\tDeleteAll\x12\x1d.identity_v2.DeleteAllRequest\x1a\x1e.identity_v2.DeleteAllResponse\"\x00\x42\x30Z.github.com/pachyderm/pachyderm/v2/src/identityb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_USER = _descriptor.Descriptor(
  name='User',
  full_name='identity_v2.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='identity_v2.User.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_authenticated', full_name='identity_v2.User.last_authenticated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=176,
)


_IDENTITYSERVERCONFIG = _descriptor.Descriptor(
  name='IdentityServerConfig',
  full_name='identity_v2.IdentityServerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer', full_name='identity_v2.IdentityServerConfig.issuer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id_token_expiry', full_name='identity_v2.IdentityServerConfig.id_token_expiry', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=241,
)


_SETIDENTITYSERVERCONFIGREQUEST = _descriptor.Descriptor(
  name='SetIdentityServerConfigRequest',
  full_name='identity_v2.SetIdentityServerConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='identity_v2.SetIdentityServerConfigRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=326,
)


_SETIDENTITYSERVERCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetIdentityServerConfigResponse',
  full_name='identity_v2.SetIdentityServerConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=361,
)


_GETIDENTITYSERVERCONFIGREQUEST = _descriptor.Descriptor(
  name='GetIdentityServerConfigRequest',
  full_name='identity_v2.GetIdentityServerConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=395,
)


_GETIDENTITYSERVERCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetIdentityServerConfigResponse',
  full_name='identity_v2.GetIdentityServerConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='identity_v2.GetIdentityServerConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=481,
)


_IDPCONNECTOR = _descriptor.Descriptor(
  name='IDPConnector',
  full_name='identity_v2.IDPConnector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='identity_v2.IDPConnector.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='identity_v2.IDPConnector.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='identity_v2.IDPConnector.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configVersion', full_name='identity_v2.IDPConnector.configVersion', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jsonConfig', full_name='identity_v2.IDPConnector.jsonConfig', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=580,
)


_CREATEIDPCONNECTORREQUEST = _descriptor.Descriptor(
  name='CreateIDPConnectorRequest',
  full_name='identity_v2.CreateIDPConnectorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connector', full_name='identity_v2.CreateIDPConnectorRequest.connector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=655,
)


_CREATEIDPCONNECTORRESPONSE = _descriptor.Descriptor(
  name='CreateIDPConnectorResponse',
  full_name='identity_v2.CreateIDPConnectorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=657,
  serialized_end=685,
)


_UPDATEIDPCONNECTORREQUEST = _descriptor.Descriptor(
  name='UpdateIDPConnectorRequest',
  full_name='identity_v2.UpdateIDPConnectorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connector', full_name='identity_v2.UpdateIDPConnectorRequest.connector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=760,
)


_UPDATEIDPCONNECTORRESPONSE = _descriptor.Descriptor(
  name='UpdateIDPConnectorResponse',
  full_name='identity_v2.UpdateIDPConnectorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=762,
  serialized_end=790,
)


_LISTIDPCONNECTORSREQUEST = _descriptor.Descriptor(
  name='ListIDPConnectorsRequest',
  full_name='identity_v2.ListIDPConnectorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=792,
  serialized_end=818,
)


_LISTIDPCONNECTORSRESPONSE = _descriptor.Descriptor(
  name='ListIDPConnectorsResponse',
  full_name='identity_v2.ListIDPConnectorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connectors', full_name='identity_v2.ListIDPConnectorsResponse.connectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=820,
  serialized_end=894,
)


_GETIDPCONNECTORREQUEST = _descriptor.Descriptor(
  name='GetIDPConnectorRequest',
  full_name='identity_v2.GetIDPConnectorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='identity_v2.GetIDPConnectorRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=932,
)


_GETIDPCONNECTORRESPONSE = _descriptor.Descriptor(
  name='GetIDPConnectorResponse',
  full_name='identity_v2.GetIDPConnectorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connector', full_name='identity_v2.GetIDPConnectorResponse.connector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=934,
  serialized_end=1005,
)


_DELETEIDPCONNECTORREQUEST = _descriptor.Descriptor(
  name='DeleteIDPConnectorRequest',
  full_name='identity_v2.DeleteIDPConnectorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='identity_v2.DeleteIDPConnectorRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1007,
  serialized_end=1046,
)


_DELETEIDPCONNECTORRESPONSE = _descriptor.Descriptor(
  name='DeleteIDPConnectorResponse',
  full_name='identity_v2.DeleteIDPConnectorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1076,
)


_OIDCCLIENT = _descriptor.Descriptor(
  name='OIDCClient',
  full_name='identity_v2.OIDCClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='identity_v2.OIDCClient.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_uris', full_name='identity_v2.OIDCClient.redirect_uris', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trusted_peers', full_name='identity_v2.OIDCClient.trusted_peers', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='identity_v2.OIDCClient.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='identity_v2.OIDCClient.secret', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1178,
)


_CREATEOIDCCLIENTREQUEST = _descriptor.Descriptor(
  name='CreateOIDCClientRequest',
  full_name='identity_v2.CreateOIDCClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='identity_v2.CreateOIDCClientRequest.client', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1180,
  serialized_end=1246,
)


_CREATEOIDCCLIENTRESPONSE = _descriptor.Descriptor(
  name='CreateOIDCClientResponse',
  full_name='identity_v2.CreateOIDCClientResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='identity_v2.CreateOIDCClientResponse.client', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1248,
  serialized_end=1315,
)


_GETOIDCCLIENTREQUEST = _descriptor.Descriptor(
  name='GetOIDCClientRequest',
  full_name='identity_v2.GetOIDCClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='identity_v2.GetOIDCClientRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1317,
  serialized_end=1351,
)


_GETOIDCCLIENTRESPONSE = _descriptor.Descriptor(
  name='GetOIDCClientResponse',
  full_name='identity_v2.GetOIDCClientResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='identity_v2.GetOIDCClientResponse.client', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1353,
  serialized_end=1417,
)


_LISTOIDCCLIENTSREQUEST = _descriptor.Descriptor(
  name='ListOIDCClientsRequest',
  full_name='identity_v2.ListOIDCClientsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1419,
  serialized_end=1443,
)


_LISTOIDCCLIENTSRESPONSE = _descriptor.Descriptor(
  name='ListOIDCClientsResponse',
  full_name='identity_v2.ListOIDCClientsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clients', full_name='identity_v2.ListOIDCClientsResponse.clients', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1445,
  serialized_end=1512,
)


_UPDATEOIDCCLIENTREQUEST = _descriptor.Descriptor(
  name='UpdateOIDCClientRequest',
  full_name='identity_v2.UpdateOIDCClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='identity_v2.UpdateOIDCClientRequest.client', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1580,
)


_UPDATEOIDCCLIENTRESPONSE = _descriptor.Descriptor(
  name='UpdateOIDCClientResponse',
  full_name='identity_v2.UpdateOIDCClientResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1582,
  serialized_end=1608,
)


_DELETEOIDCCLIENTREQUEST = _descriptor.Descriptor(
  name='DeleteOIDCClientRequest',
  full_name='identity_v2.DeleteOIDCClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='identity_v2.DeleteOIDCClientRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1610,
  serialized_end=1647,
)


_DELETEOIDCCLIENTRESPONSE = _descriptor.Descriptor(
  name='DeleteOIDCClientResponse',
  full_name='identity_v2.DeleteOIDCClientResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1649,
  serialized_end=1675,
)


_DELETEALLREQUEST = _descriptor.Descriptor(
  name='DeleteAllRequest',
  full_name='identity_v2.DeleteAllRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1677,
  serialized_end=1695,
)


_DELETEALLRESPONSE = _descriptor.Descriptor(
  name='DeleteAllResponse',
  full_name='identity_v2.DeleteAllResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1697,
  serialized_end=1716,
)

_USER.fields_by_name['last_authenticated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SETIDENTITYSERVERCONFIGREQUEST.fields_by_name['config'].message_type = _IDENTITYSERVERCONFIG
_GETIDENTITYSERVERCONFIGRESPONSE.fields_by_name['config'].message_type = _IDENTITYSERVERCONFIG
_CREATEIDPCONNECTORREQUEST.fields_by_name['connector'].message_type = _IDPCONNECTOR
_UPDATEIDPCONNECTORREQUEST.fields_by_name['connector'].message_type = _IDPCONNECTOR
_LISTIDPCONNECTORSRESPONSE.fields_by_name['connectors'].message_type = _IDPCONNECTOR
_GETIDPCONNECTORRESPONSE.fields_by_name['connector'].message_type = _IDPCONNECTOR
_CREATEOIDCCLIENTREQUEST.fields_by_name['client'].message_type = _OIDCCLIENT
_CREATEOIDCCLIENTRESPONSE.fields_by_name['client'].message_type = _OIDCCLIENT
_GETOIDCCLIENTRESPONSE.fields_by_name['client'].message_type = _OIDCCLIENT
_LISTOIDCCLIENTSRESPONSE.fields_by_name['clients'].message_type = _OIDCCLIENT
_UPDATEOIDCCLIENTREQUEST.fields_by_name['client'].message_type = _OIDCCLIENT
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['IdentityServerConfig'] = _IDENTITYSERVERCONFIG
DESCRIPTOR.message_types_by_name['SetIdentityServerConfigRequest'] = _SETIDENTITYSERVERCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetIdentityServerConfigResponse'] = _SETIDENTITYSERVERCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['GetIdentityServerConfigRequest'] = _GETIDENTITYSERVERCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetIdentityServerConfigResponse'] = _GETIDENTITYSERVERCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['IDPConnector'] = _IDPCONNECTOR
DESCRIPTOR.message_types_by_name['CreateIDPConnectorRequest'] = _CREATEIDPCONNECTORREQUEST
DESCRIPTOR.message_types_by_name['CreateIDPConnectorResponse'] = _CREATEIDPCONNECTORRESPONSE
DESCRIPTOR.message_types_by_name['UpdateIDPConnectorRequest'] = _UPDATEIDPCONNECTORREQUEST
DESCRIPTOR.message_types_by_name['UpdateIDPConnectorResponse'] = _UPDATEIDPCONNECTORRESPONSE
DESCRIPTOR.message_types_by_name['ListIDPConnectorsRequest'] = _LISTIDPCONNECTORSREQUEST
DESCRIPTOR.message_types_by_name['ListIDPConnectorsResponse'] = _LISTIDPCONNECTORSRESPONSE
DESCRIPTOR.message_types_by_name['GetIDPConnectorRequest'] = _GETIDPCONNECTORREQUEST
DESCRIPTOR.message_types_by_name['GetIDPConnectorResponse'] = _GETIDPCONNECTORRESPONSE
DESCRIPTOR.message_types_by_name['DeleteIDPConnectorRequest'] = _DELETEIDPCONNECTORREQUEST
DESCRIPTOR.message_types_by_name['DeleteIDPConnectorResponse'] = _DELETEIDPCONNECTORRESPONSE
DESCRIPTOR.message_types_by_name['OIDCClient'] = _OIDCCLIENT
DESCRIPTOR.message_types_by_name['CreateOIDCClientRequest'] = _CREATEOIDCCLIENTREQUEST
DESCRIPTOR.message_types_by_name['CreateOIDCClientResponse'] = _CREATEOIDCCLIENTRESPONSE
DESCRIPTOR.message_types_by_name['GetOIDCClientRequest'] = _GETOIDCCLIENTREQUEST
DESCRIPTOR.message_types_by_name['GetOIDCClientResponse'] = _GETOIDCCLIENTRESPONSE
DESCRIPTOR.message_types_by_name['ListOIDCClientsRequest'] = _LISTOIDCCLIENTSREQUEST
DESCRIPTOR.message_types_by_name['ListOIDCClientsResponse'] = _LISTOIDCCLIENTSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateOIDCClientRequest'] = _UPDATEOIDCCLIENTREQUEST
DESCRIPTOR.message_types_by_name['UpdateOIDCClientResponse'] = _UPDATEOIDCCLIENTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteOIDCClientRequest'] = _DELETEOIDCCLIENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteOIDCClientResponse'] = _DELETEOIDCCLIENTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllRequest'] = _DELETEALLREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllResponse'] = _DELETEALLRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.User)
  })
_sym_db.RegisterMessage(User)

IdentityServerConfig = _reflection.GeneratedProtocolMessageType('IdentityServerConfig', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYSERVERCONFIG,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.IdentityServerConfig)
  })
_sym_db.RegisterMessage(IdentityServerConfig)

SetIdentityServerConfigRequest = _reflection.GeneratedProtocolMessageType('SetIdentityServerConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETIDENTITYSERVERCONFIGREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.SetIdentityServerConfigRequest)
  })
_sym_db.RegisterMessage(SetIdentityServerConfigRequest)

SetIdentityServerConfigResponse = _reflection.GeneratedProtocolMessageType('SetIdentityServerConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETIDENTITYSERVERCONFIGRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.SetIdentityServerConfigResponse)
  })
_sym_db.RegisterMessage(SetIdentityServerConfigResponse)

GetIdentityServerConfigRequest = _reflection.GeneratedProtocolMessageType('GetIdentityServerConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETIDENTITYSERVERCONFIGREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.GetIdentityServerConfigRequest)
  })
_sym_db.RegisterMessage(GetIdentityServerConfigRequest)

GetIdentityServerConfigResponse = _reflection.GeneratedProtocolMessageType('GetIdentityServerConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETIDENTITYSERVERCONFIGRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.GetIdentityServerConfigResponse)
  })
_sym_db.RegisterMessage(GetIdentityServerConfigResponse)

IDPConnector = _reflection.GeneratedProtocolMessageType('IDPConnector', (_message.Message,), {
  'DESCRIPTOR' : _IDPCONNECTOR,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.IDPConnector)
  })
_sym_db.RegisterMessage(IDPConnector)

CreateIDPConnectorRequest = _reflection.GeneratedProtocolMessageType('CreateIDPConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEIDPCONNECTORREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.CreateIDPConnectorRequest)
  })
_sym_db.RegisterMessage(CreateIDPConnectorRequest)

CreateIDPConnectorResponse = _reflection.GeneratedProtocolMessageType('CreateIDPConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEIDPCONNECTORRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.CreateIDPConnectorResponse)
  })
_sym_db.RegisterMessage(CreateIDPConnectorResponse)

UpdateIDPConnectorRequest = _reflection.GeneratedProtocolMessageType('UpdateIDPConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEIDPCONNECTORREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.UpdateIDPConnectorRequest)
  })
_sym_db.RegisterMessage(UpdateIDPConnectorRequest)

UpdateIDPConnectorResponse = _reflection.GeneratedProtocolMessageType('UpdateIDPConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEIDPCONNECTORRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.UpdateIDPConnectorResponse)
  })
_sym_db.RegisterMessage(UpdateIDPConnectorResponse)

ListIDPConnectorsRequest = _reflection.GeneratedProtocolMessageType('ListIDPConnectorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTIDPCONNECTORSREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.ListIDPConnectorsRequest)
  })
_sym_db.RegisterMessage(ListIDPConnectorsRequest)

ListIDPConnectorsResponse = _reflection.GeneratedProtocolMessageType('ListIDPConnectorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTIDPCONNECTORSRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.ListIDPConnectorsResponse)
  })
_sym_db.RegisterMessage(ListIDPConnectorsResponse)

GetIDPConnectorRequest = _reflection.GeneratedProtocolMessageType('GetIDPConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETIDPCONNECTORREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.GetIDPConnectorRequest)
  })
_sym_db.RegisterMessage(GetIDPConnectorRequest)

GetIDPConnectorResponse = _reflection.GeneratedProtocolMessageType('GetIDPConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETIDPCONNECTORRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.GetIDPConnectorResponse)
  })
_sym_db.RegisterMessage(GetIDPConnectorResponse)

DeleteIDPConnectorRequest = _reflection.GeneratedProtocolMessageType('DeleteIDPConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEIDPCONNECTORREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.DeleteIDPConnectorRequest)
  })
_sym_db.RegisterMessage(DeleteIDPConnectorRequest)

DeleteIDPConnectorResponse = _reflection.GeneratedProtocolMessageType('DeleteIDPConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEIDPCONNECTORRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.DeleteIDPConnectorResponse)
  })
_sym_db.RegisterMessage(DeleteIDPConnectorResponse)

OIDCClient = _reflection.GeneratedProtocolMessageType('OIDCClient', (_message.Message,), {
  'DESCRIPTOR' : _OIDCCLIENT,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.OIDCClient)
  })
_sym_db.RegisterMessage(OIDCClient)

CreateOIDCClientRequest = _reflection.GeneratedProtocolMessageType('CreateOIDCClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEOIDCCLIENTREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.CreateOIDCClientRequest)
  })
_sym_db.RegisterMessage(CreateOIDCClientRequest)

CreateOIDCClientResponse = _reflection.GeneratedProtocolMessageType('CreateOIDCClientResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEOIDCCLIENTRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.CreateOIDCClientResponse)
  })
_sym_db.RegisterMessage(CreateOIDCClientResponse)

GetOIDCClientRequest = _reflection.GeneratedProtocolMessageType('GetOIDCClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOIDCCLIENTREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.GetOIDCClientRequest)
  })
_sym_db.RegisterMessage(GetOIDCClientRequest)

GetOIDCClientResponse = _reflection.GeneratedProtocolMessageType('GetOIDCClientResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOIDCCLIENTRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.GetOIDCClientResponse)
  })
_sym_db.RegisterMessage(GetOIDCClientResponse)

ListOIDCClientsRequest = _reflection.GeneratedProtocolMessageType('ListOIDCClientsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTOIDCCLIENTSREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.ListOIDCClientsRequest)
  })
_sym_db.RegisterMessage(ListOIDCClientsRequest)

ListOIDCClientsResponse = _reflection.GeneratedProtocolMessageType('ListOIDCClientsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTOIDCCLIENTSRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.ListOIDCClientsResponse)
  })
_sym_db.RegisterMessage(ListOIDCClientsResponse)

UpdateOIDCClientRequest = _reflection.GeneratedProtocolMessageType('UpdateOIDCClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEOIDCCLIENTREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.UpdateOIDCClientRequest)
  })
_sym_db.RegisterMessage(UpdateOIDCClientRequest)

UpdateOIDCClientResponse = _reflection.GeneratedProtocolMessageType('UpdateOIDCClientResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEOIDCCLIENTRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.UpdateOIDCClientResponse)
  })
_sym_db.RegisterMessage(UpdateOIDCClientResponse)

DeleteOIDCClientRequest = _reflection.GeneratedProtocolMessageType('DeleteOIDCClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOIDCCLIENTREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.DeleteOIDCClientRequest)
  })
_sym_db.RegisterMessage(DeleteOIDCClientRequest)

DeleteOIDCClientResponse = _reflection.GeneratedProtocolMessageType('DeleteOIDCClientResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOIDCCLIENTRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.DeleteOIDCClientResponse)
  })
_sym_db.RegisterMessage(DeleteOIDCClientResponse)

DeleteAllRequest = _reflection.GeneratedProtocolMessageType('DeleteAllRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALLREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.DeleteAllRequest)
  })
_sym_db.RegisterMessage(DeleteAllRequest)

DeleteAllResponse = _reflection.GeneratedProtocolMessageType('DeleteAllResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALLRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.DeleteAllResponse)
  })
_sym_db.RegisterMessage(DeleteAllResponse)


DESCRIPTOR._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='identity_v2.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1719,
  serialized_end=3038,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetIdentityServerConfig',
    full_name='identity_v2.API.SetIdentityServerConfig',
    index=0,
    containing_service=None,
    input_type=_SETIDENTITYSERVERCONFIGREQUEST,
    output_type=_SETIDENTITYSERVERCONFIGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIdentityServerConfig',
    full_name='identity_v2.API.GetIdentityServerConfig',
    index=1,
    containing_service=None,
    input_type=_GETIDENTITYSERVERCONFIGREQUEST,
    output_type=_GETIDENTITYSERVERCONFIGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateIDPConnector',
    full_name='identity_v2.API.CreateIDPConnector',
    index=2,
    containing_service=None,
    input_type=_CREATEIDPCONNECTORREQUEST,
    output_type=_CREATEIDPCONNECTORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateIDPConnector',
    full_name='identity_v2.API.UpdateIDPConnector',
    index=3,
    containing_service=None,
    input_type=_UPDATEIDPCONNECTORREQUEST,
    output_type=_UPDATEIDPCONNECTORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListIDPConnectors',
    full_name='identity_v2.API.ListIDPConnectors',
    index=4,
    containing_service=None,
    input_type=_LISTIDPCONNECTORSREQUEST,
    output_type=_LISTIDPCONNECTORSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIDPConnector',
    full_name='identity_v2.API.GetIDPConnector',
    index=5,
    containing_service=None,
    input_type=_GETIDPCONNECTORREQUEST,
    output_type=_GETIDPCONNECTORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteIDPConnector',
    full_name='identity_v2.API.DeleteIDPConnector',
    index=6,
    containing_service=None,
    input_type=_DELETEIDPCONNECTORREQUEST,
    output_type=_DELETEIDPCONNECTORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateOIDCClient',
    full_name='identity_v2.API.CreateOIDCClient',
    index=7,
    containing_service=None,
    input_type=_CREATEOIDCCLIENTREQUEST,
    output_type=_CREATEOIDCCLIENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateOIDCClient',
    full_name='identity_v2.API.UpdateOIDCClient',
    index=8,
    containing_service=None,
    input_type=_UPDATEOIDCCLIENTREQUEST,
    output_type=_UPDATEOIDCCLIENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOIDCClient',
    full_name='identity_v2.API.GetOIDCClient',
    index=9,
    containing_service=None,
    input_type=_GETOIDCCLIENTREQUEST,
    output_type=_GETOIDCCLIENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOIDCClients',
    full_name='identity_v2.API.ListOIDCClients',
    index=10,
    containing_service=None,
    input_type=_LISTOIDCCLIENTSREQUEST,
    output_type=_LISTOIDCCLIENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteOIDCClient',
    full_name='identity_v2.API.DeleteOIDCClient',
    index=11,
    containing_service=None,
    input_type=_DELETEOIDCCLIENTREQUEST,
    output_type=_DELETEOIDCCLIENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAll',
    full_name='identity_v2.API.DeleteAll',
    index=12,
    containing_service=None,
    input_type=_DELETEALLREQUEST,
    output_type=_DELETEALLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)
